Credits — lenstronomy 1.8.2 documentation

# Credits

## Development Lead

- Simon Birrer <sibirrer@gmail.com> sibirrer

## Key contributors

- Anowar Shajib ajshajib
- Aymeric Galan aymgal
- Daniel Gilman dangilman

## Contributors (alphabetic)

- Jelle Aalbers JelleAalbers
- Joel Akeret jakeret
- Adam Amara aamara
- Xuheng Ding dartoon
- Kevin Fusshoeller
- Felix A. Kuhn
- Felix Mayor
- Martin Millon martin-millon
- Robert Morgan rmorgan10
- Anna Nierenberg amn3142
- Brian Nord bnord
- Giulia Pagano
- Ji Won Park jiwoncpark
- Thomas Schmidt Thomas-01
- Dominique Sluse
- Luca Teodori lucateo
- Nicolas Tessore ntessore
- Madison Ueland mueland
- Lyne Van de Vyvere LyneVdV
- Sebastian Wagner-Carena swagnercarena
- Cyril Welschen
- Ewoud Wempe ewoudwempe
- Lilan Yang ylilan